@@ -1,10 +1,12 @@
-from .core import URLMetadataCache
+from typing import Optional
+
+from .core import URLMetadataCache, Metadata
 
 # uncustomized, basic entry point to the library
-default_cache = None
+default_cache: Optional[URLMetadataCache] = None
 
 
-def metadata(url):
+def metadata(url: str) -> Metadata:
     global default_cache
     if default_cache is None:
         default_cache = URLMetadataCache()
