@@ -5,11 +5,11 @@ from pathlib import Path
 from typing import List, Dict, Any
 
 import pytest
-import vcr # type: ignore[import]
+import vcr  # type: ignore[import]
 
 from url_metadata.core import URLMetadataCache, Metadata
 from url_metadata.cache import DirCache
-from url_metadata.youtube import get_yt_video_id
+from url_metadata.sites.youtube import get_yt_video_id
 
 
 @pytest.fixture()
@@ -26,8 +26,10 @@ youtube_without_cc = "https://youtu.be/xvQUiX26RfE"
 github_home = "https://github.com"
 image_file = "https://i.picsum.photos/id/1000/367/267.jpg?hmac=uO9iQNujyGpqk0Ieytv_xfwbpy3ENW4PhnIZ1gsnldI"
 
+tests_dir = os.path.dirname(os.path.abspath(__file__))
 
-@vcr.use_cassette("tests/vcr/youtube_subs.yaml")
+
+@vcr.use_cassette(os.path.join(tests_dir, "vcr/youtube_subs.yaml"))
 def test_youtube_has_subtitles(ucache) -> None:
 
     # make sure subtitles download to file
@@ -53,7 +55,7 @@ def test_youtube_has_subtitles(ucache) -> None:
     assert "trade-off between space and time" in subtitles_file.read_text()
 
 
-@vcr.use_cassette("tests/vcr/youtube_no_subs.yaml")
+@vcr.use_cassette(os.path.join(tests_dir, "vcr/youtube_no_subs.yaml"))
 def test_doesnt_have_subtitles(ucache) -> None:
     meta_resp = ucache.get(youtube_without_cc)
     # make sure this parsed the youtube id
@@ -62,9 +64,14 @@ def test_doesnt_have_subtitles(ucache) -> None:
     dir_full_path = ucache.metadata_cache.cache.get(youtube_without_cc)
     assert not os.path.exists(os.path.join(dir_full_path, "subtitles.srt"))
     assert os.path.exists(os.path.join(dir_full_path, "metadata.json"))
-    assert os.path.exists(os.path.join(dir_full_path, "summary.html"))
+    # this deletes the summary files on purpose, since theyre somewhat useless
+    assert not os.path.exists(os.path.join(dir_full_path, "summary.html"))
+    assert not os.path.exists(os.path.join(dir_full_path, "summary.txt"))
 
-@vcr.use_cassette("tests/vcr/skip_downloading_youtube_subtitles.yaml")
+
+@vcr.use_cassette(
+    os.path.join(tests_dir, "vcr/skip_downloading_youtube_subtitles.yaml")
+)
 def test_skip_downloading_youtube_subtitles(ucache) -> None:
 
     # see if this URL would succeed usually, download subtitles
@@ -86,7 +93,7 @@ def test_skip_downloading_youtube_subtitles(ucache) -> None:
     assert meta_resp.subtitles is None
 
 
-@vcr.use_cassette("tests/vcr/generic_url.yaml")
+@vcr.use_cassette(os.path.join(tests_dir, "vcr/generic_url.yaml"))
 def test_generic_url(ucache):
     meta_resp = ucache.get(github_home)
     assert ucache.in_cache(github_home)
@@ -102,7 +109,7 @@ def test_generic_url(ucache):
     assert os.path.exists(os.path.join(dir_full_path, "metadata.json"))
 
 
-@vcr.use_cassette("tests/vcr/test_image.yaml")
+@vcr.use_cassette(os.path.join(tests_dir, "vcr/test_image.yaml"))
 def test_image(ucache) -> None:
 
     # test text_summary doesnt exist for image file, since it doesnt have any
@@ -124,5 +131,3 @@ def test_image(ucache) -> None:
     assert not os.path.exists(os.path.join(dir_full_path, "summary.html"))
     assert not os.path.exists(os.path.join(dir_full_path, "summary.txt"))
     assert os.path.exists(os.path.join(dir_full_path, "metadata.json"))
-
-
